@@ -1,8 +1,9 @@
 from functools import lru_cache
-from typing import Dict, List, Literal, Optional
+from typing import Dict, List, Optional
 
 import numpy as np
 import pandas as pd
+from typing_extensions import Literal
 
 from . import fields as fld
 from . import utils
